services.log package — Platform V1.0 documentation

Platform V1.0 documentation

# services.log package

## Submodules

## services.log.conn_web_log module

class `services.log.conn_web_log.` `ConnWebLogService`

  Bases: `system.app.App`

  Support all syslog.

      >>> from nameko.standalone.rpc import ClusterRpcProxy
      >>> CONFIG = {"AMQP_URI":"amqp://guest:guest@localhost"}
      >>> with ClusterRpcProxy(CONFIG) as services:
      >>>     result = services.conn_web_log_service.add_log({"content": "info"})

  `add_log`(content)

    Add a log.

  `name` = 'conn_web_log_service'

## services.log.log module

class `services.log.log.` `LogService`

  Bases: `system.app.App`

  Support all syslog.

      >>> from nameko.standalone.rpc import ClusterRpcProxy
      >>> CONFIG = {"AMQP_URI":"amqp://guest:guest@localhost"}
      >>> with ClusterRpcProxy(CONFIG) as services:
      >>>     result = services.log_service.add_log({"content": "info"})

  `add_log`(content)

    Add a log.

  `name` = 'log_service'

## services.log.user_event_log module

class `services.log.user_event_log.` `UserEventLogService`

  Bases: `system.app.App`

  Support all syslog.

      >>> from nameko.standalone.rpc import ClusterRpcProxy
      >>> CONFIG = {"AMQP_URI":"amqp://guest:guest@localhost"}
      >>> with ClusterRpcProxy(CONFIG) as services:
      >>>     result = services.user_event_log_service.add_log({"content": "info"})

  `add_log`(content)

    Add a log.

  `get_log`(query)

    Get logs.

  `name` = 'user_event_log_service'

## Module contents